@@ -23,7 +23,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
 __author__ = 'Alexandre Norman (norman at xael.org)'
-__version__ = '0.4.1'
+__version__ = '0.4.3'
 __last_modification__ = '2015.06.13'
 
 import copy
@@ -497,7 +497,7 @@ import gantt
 
 
 
-    if planning_end_date <= planning_start_date:
+    if eval(planning_end_date) <= eval(planning_start_date):
         __LOG__.critical('planning_end_date [{0}] is before planning_start_date [{1}]...'.format(planning_end_date, planning_start_date))
         sys.exit(-1)
 
